package com.example.depanntout

import android.content.Context
import android.util.Log
import android.widget.Toast
import com.android.volley.Request
import com.android.volley.Response
import com.android.volley.toolbox.JsonArrayRequest
import com.android.volley.toolbox.JsonObjectRequest
import com.android.volley.toolbox.Volley
import com.example.depanntout.bdd.Intervention
import org.json.JSONArray

class Importation {
    fun importInterventionsFromServer(context: Context, callback: (List<Intervention>) -> Unit) {
        val url = "http://192.168.48.185:8000/interventions"
        val queue = Volley.newRequestQueue(context)

        val interventionsList = mutableListOf<Intervention>()

        val jsonObjectRequest = JsonArrayRequest(
            Request.Method.GET,
            url,
            null,
            { response ->
                val interventionsArray = response as JSONArray
                for (i in 0 until interventionsArray.length()) {
                    val interventionJson = interventionsArray.getJSONObject(i)
                    val intervention = Intervention(
                        idIntervention = interventionJson.getInt("idIntervention"),
                        datetime = interventionJson.getString("date"),
                        observation = interventionJson.getString("observation"),
                        idClient = interventionJson.getInt("idClient")
                    )
                    interventionsList.add(intervention)
                }
                Toast.makeText(context, "Server response: ${interventionsList.size} interventions loaded", Toast.LENGTH_LONG).show()

                callback(interventionsList)
            },
            { error ->
                Toast.makeText(context, "Server error: ${error.message}", Toast.LENGTH_SHORT).show()
                callback(emptyList())
            }
        )

        queue.add(jsonObjectRequest)
    }

    fun importClientsFromServer(context: Context, callback: (List<Client>) -> Unit) {
        val url = "http://192.168.48.185:8000/clients"
        val queue = Volley.newRequestQueue(context)

        val clientsList = mutableListOf<Client>()

        val jsonObjectRequest = JsonArrayRequest(
            Request.Method.GET,
            url,
            null,
            { response ->
                val clientsArray = response as JSONArray
                for (i in 0 until clientsArray.length()) {
                    val clientJson = clientsArray.getJSONObject(i)
                    val client = Client(
                        idClient = clientJson.getInt("idClient"),
                        fistname = clientJson.getString("nom"),
                        lastname = clientJson.getString("prenom"),
                        email = clientJson.getString("email"),
                        tel = clientJson.getString("telephone"),
                        adresse = clientJson.getString("adresse"),
                    )
                    clientsList.add(client)
                }
                Toast.makeText(context, "Server response: ${clientsList.size} clients loaded", Toast.LENGTH_LONG).show()

                callback(clientsList)
            },
            { error ->
                Toast.makeText(context, "Server error: ${error.message}", Toast.LENGTH_SHORT).show()
                callback(emptyList())
            }
        )

        queue.add(jsonObjectRequest)
    }
}